%{
#include <stdio.h>
#include "lexerstates.h"


extern int my_yyinput(char *buf, int max_size);
#undef YY_INPUT
#define YY_INPUT(b, r, ms)	(r = my_yyinput(b,ms))
%}
%option noyywrap
%%
0[0-7]*	{ return OCTNUM; }
[1-9][0-9]*	{ return INTEGER; }
-[0-9]+	{ return INTEGER; }
0x[0-9A-Fa-f]+		{ return HEXNUM; }
[0-9A-Fa-f]+[Hh]	{ return HEXNUM; }
0b[01]+		{ return BINNUM; }
b'[01]+'	{ return BINNUM; }
[A-Za-z_$@][0-9A-Za-z_]*	{ return STRING; }
\+		{ return PLUS; }
-		{ return MINUS; }
\*		{ return TIMES; }
\/		{ return DIVIDE; }
\%		{ return MOD; }
\<<		{ return SHIFTLEFT; }
>>		{ return SHIFTRIGHT; }
&		{ return BIT_AND; }
\|		{ return BIT_OR; }
\^		{ return BIT_XOR; }
\(		{ return OPAREN; }
\)		{ return CPAREN; }
\?		{ return TERNARY; }
:		{ return COLON; }
==		{ return EQUAL; }
!=		{ return NOTEQUAL; }
\<		{ return LESSTHAN; }
\<=		{ return LESSEQUAL; }
>		{ return GREATERTHAN; }
>=		{ return GREATEREQUAL; }
!		{ return LOGIC_NOT; }
\~		{ return BIT_NOT; }
&&		{ return LOGIC_AND; }
\|\|		{ return LOGIC_OR; }
\^\^		{ return LOGIC_XOR; }
:h([^0-9A-Za-z_]|$)	{ return HIBYTE; }
:l([^0-9A-Za-z_]|$)	{ return LOBYTE; }


.|\n	{ ; }	/* Ignore non-matched characters */
%%

